__docformat__ = 'reStructuredText'

# pylint: disable=multiple-statements
# pylint: disable=line-too-long
# pylint: disable=consider-using-f-string
# pylint: disable=no-member

__package_name__ = "rickslab_gopass_utils"
__version__ = "0.5.0"
__name__ = "gopass_utils"
